#!/usr/bin/env python3

# Copyright (c) 2021 Cisco and/or its affiliates.
#
# SPDX-License-Identifier: Apache-2.0 OR GPL-2.0-or-later
#
# Licensed under the Apache License 2.0 or
# GNU General Public License v2.0 or later;  you may not use this file
# except in compliance with one of these Licenses. You
# may obtain a copy of the Licenses at:
#
#     http://www.apache.org/licenses/LICENSE-2.0
#     https://www.gnu.org/licenses/old-licenses/gpl-2.0-standalone.html
#
# Note: If this file is linked with Scapy, which is GPLv2+, your use of it
# must be under GPLv2+.  If at any point in the future it is no longer linked
# with Scapy (or other GPLv2+ licensed software), you are free to choose
# Apache 2.
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Functions simplifying address validation."""

import ipaddress


def valid_ipv4(ip_address):
    """Check IPv4 address.

    :param ip_address: IPv4 address to check.
    :type ip_address: str
    :returns: True if IP address is correct.
    :rtype: bool
    """
    try:
        ipaddress.IPv4Address(ip_address)
        return True
    except (AttributeError, ipaddress.AddressValueError):
        return False


def valid_ipv6(ip_address):
    """Check IPv6 address.

    :param ip_address: IPv6 address to check.
    :type ip_address: str
    :returns: True if IP address is correct.
    :rtype: bool
    """
    try:
        ipaddress.IPv6Address(ip_address)
        return True
    except (AttributeError, ipaddress.AddressValueError):
        return False
